@@ -114,168 +114,164 @@ function HastexoXBlock(runtime, element, configuration) {
           terminal_ws_url = prot_map[location.protocol] + '//' + location.hostname + configuration.terminal_url;
         }
 
-        /* Load app dynamically. */
-        $.cachedScript(terminal_http_url + 'guacamole-common-js/all.min.js').done(function() {
-            terminal_client = new Guacamole.Client(
-                new Guacamole.WebSocketTunnel(terminal_ws_url + "websocket-tunnel")
-            );
-            terminal_element = terminal_client.getDisplay().getElement();
+        /* Initialize Guacamole Client */
+        terminal_client = new Guacamole.Client(
+            new Guacamole.WebSocketTunnel(terminal_ws_url + "websocket-tunnel")
+        );
+        terminal_element = terminal_client.getDisplay().getElement();
 
-            /* Show the terminal.  */
-            $("#terminal").append(terminal_element);
+        /* Show the terminal.  */
+        $("#terminal").append(terminal_element);
 
-            /* Disconnect on tab close. */
-            window.onunload = function() {
-                terminal_client.disconnect();
-            };
+        /* Disconnect on tab close. */
+        window.onunload = function() {
+            terminal_client.disconnect();
+        };
 
-            if(!configuration.read_only) {
-                /* Mouse handling */
-                var mouse = new Guacamole.Mouse(terminal_element);
+        /* Mouse handling */
+        var mouse = new Guacamole.Mouse(terminal_element);
 
-                mouse.onmousedown =
-                mouse.onmouseup   =
-                mouse.onmousemove = function(mouseState) {
-                    terminal_client.sendMouseState(mouseState);
+        mouse.onmousedown =
+        mouse.onmouseup   =
+        mouse.onmousemove = function(mouseState) {
+            terminal_client.sendMouseState(mouseState);
 
-                    /* Reset the idle timeout on mouse action. */
-                    if (configuration.timeouts['idle']) {
-                        if (idle_timer) clearTimeout(idle_timer);
-                        idle_timer = setTimeout(idle, configuration.timeouts['idle']);
-                    }
-                };
+            /* Reset the idle timeout on mouse action. */
+            if (configuration.timeouts['idle']) {
+                if (idle_timer) clearTimeout(idle_timer);
+                idle_timer = setTimeout(idle, configuration.timeouts['idle']);
+            }
+        };
 
-                /* Keyboard handling.  */
-                var keyboard = new Guacamole.Keyboard(terminal_element);
-                var ctrl, shift = false;
+        /* Keyboard handling.  */
+        var keyboard = new Guacamole.Keyboard(terminal_element);
+        var ctrl, shift = false;
 
-                keyboard.onkeydown = function (keysym) {
-                    var cancel_event = true;
+        keyboard.onkeydown = function (keysym) {
+            var cancel_event = true;
 
-                    /* Don't cancel event on paste shortcuts. */
-                    if (keysym == 0xFFE1 /* shift */
-                        || keysym == 0xFFE3 /* ctrl */
-                        || keysym == 0xFF63 /* insert */
-                        || keysym == 0x0056 /* V */
-                        || keysym == 0x0076 /* v */
-                    ) {
-                        cancel_event = false;
-                    }
-
-                    /* Remember when ctrl or shift are down. */
-                    if (keysym == 0xFFE1) {
-                        shift = true;
-                    } else if (keysym == 0xFFE3) {
-                        ctrl = true;
-                    }
-
-                    /* Delay sending final stroke until clipboard is updated. */
-                    if ((ctrl && shift && keysym == 0x0056) /* ctrl-shift-V */
-                        || (ctrl && keysym == 0x0076) /* ctrl-v */
-                        || (shift && keysym == 0xFF63) /* shift-insert */
-                    ) {
-                        window.setTimeout(function() {
-                            terminal_client.sendKeyEvent(1, keysym);
-                        }, 50);
-                    } else {
-                        terminal_client.sendKeyEvent(1, keysym);
-                    }
-
-                    return !cancel_event;
-                };
-
-                keyboard.onkeyup = function (keysym) {
-                    /* Remember when ctrl or shift are released. */
-                    if (keysym == 0xFFE1) {
-                        shift = false;
-                    } else if (keysym == 0xFFE3) {
-                        ctrl = false;
-                    }
-
-                    /* Delay sending final stroke until clipboard is updated. */
-                    if ((ctrl && shift && keysym == 0x0056) /* ctrl-shift-v */
-                        || (ctrl && keysym == 0x0076) /* ctrl-v */
-                        || (shift && keysym == 0xFF63) /* shift-insert */
-                    ) {
-                        window.setTimeout(function() {
-                            terminal_client.sendKeyEvent(0, keysym);
-                        }, 50);
-                    } else {
-                        terminal_client.sendKeyEvent(0, keysym);
-                    }
-                };
-
-                $(terminal_element)
-                    /* Set tabindex so that element can be focused.  Otherwise, no
-                    * keyboard events will be registered for it. */
-                    .attr('tabindex', 1)
-                    /* Focus on the element based on mouse movement.  Simply
-                    * letting the user click on it doesn't work. */
-                    .hover(
-                        function() {
-                        var x = window.scrollX, y = window.scrollY;
-                        $(this).focus();
-                        window.scrollTo(x, y);
-                        }, function() {
-                        $(this).blur();
-                        }
-                    )
-                    /* Release all keys when the element loses focus. */
-                    .blur(function() {
-                        keyboard.reset();
-                    });
-
-                /* Handle paste events when the element is in focus. */
-                $(document).on('paste', function(e) {
-                    var text = e.originalEvent.clipboardData.getData('text/plain');
-                    if ($(terminal_element).is(":focus")) {
-                        terminal_client.setClipboard(text);
-                    }
-                });
+            /* Don't cancel event on paste shortcuts. */
+            if (keysym == 0xFFE1 /* shift */
+                || keysym == 0xFFE3 /* ctrl */
+                || keysym == 0xFF63 /* insert */
+                || keysym == 0x0056 /* V */
+                || keysym == 0x0076 /* v */
+            ) {
+                cancel_event = false;
             }
 
-            /* Error handling. */
-            terminal_client.onerror = function(guac_error) {
-                /* Reset and disconnect. */
-                if (keepalive_timer) clearTimeout(keepalive_timer);
-                if (idle_timer) clearTimeout(idle_timer);
-                stack = null;
-                terminal_client.disconnect();
+            /* Remember when ctrl or shift are down. */
+            if (keysym == 0xFFE1) {
+                shift = true;
+            } else if (keysym == 0xFFE3) {
+                ctrl = true;
+            }
 
-                var dialog = $('#launch_error');
-                var dialog_message =
-                    "Could not connect to your lab environment. " +
-                    "The client detected an unexpected error. " +
-                    "The server's error message was:";
-                var error_message = guac_error.message;
-                /* Special-case the unhelpful "Aborted. See logs"
-                 * message, indicating that although we did have a
-                 * working connection earlier, we've now lost it (as
-                 * opposed to never being able to connect to the
-                 * upstream web socket at all). For any other message,
-                 * just pass through the error received from
-                 * upstream. */
-                if (guac_error.message.toLowerCase().startsWith('aborted')) {
-                    dialog_message = "Lost connection to your lab environment."
-                    error_message =
-                        "The remote server unexpectedly disconnected. " +
-                        "You can try closing your browser window, " +
-                        "and returning to this page in a few minutes.";
+            /* Delay sending final stroke until clipboard is updated. */
+            if ((ctrl && shift && keysym == 0x0056) /* ctrl-shift-V */
+                || (ctrl && keysym == 0x0076) /* ctrl-v */
+                || (shift && keysym == 0xFF63) /* shift-insert */
+            ) {
+                window.setTimeout(function() {
+                    terminal_client.sendKeyEvent(1, keysym);
+                }, 50);
+            } else {
+                terminal_client.sendKeyEvent(1, keysym);
+            }
+
+            return !cancel_event;
+        };
+
+        keyboard.onkeyup = function (keysym) {
+            /* Remember when ctrl or shift are released. */
+            if (keysym == 0xFFE1) {
+                shift = false;
+            } else if (keysym == 0xFFE3) {
+                ctrl = false;
+            }
+
+            /* Delay sending final stroke until clipboard is updated. */
+            if ((ctrl && shift && keysym == 0x0056) /* ctrl-shift-v */
+                || (ctrl && keysym == 0x0076) /* ctrl-v */
+                || (shift && keysym == 0xFF63) /* shift-insert */
+            ) {
+                window.setTimeout(function() {
+                    terminal_client.sendKeyEvent(0, keysym);
+                }, 50);
+            } else {
+                terminal_client.sendKeyEvent(0, keysym);
+            }
+        };
+
+        $(terminal_element)
+            /* Set tabindex so that element can be focused.  Otherwise, no
+            * keyboard events will be registered for it. */
+            .attr('tabindex', 1)
+            /* Focus on the element based on mouse movement.  Simply
+            * letting the user click on it doesn't work. */
+            .hover(
+                function() {
+                var x = window.scrollX, y = window.scrollY;
+                $(this).focus();
+                window.scrollTo(x, y);
+                }, function() {
+                $(this).blur();
                 }
-                dialog.find('.message').html(dialog_message);
-                dialog.find('.error_msg').html(error_message);
-                dialog.find('input.ok').one('click', function() {
-                    $.dialog.close();
-                });
-                dialog.find('input.retry').one('click', function() {
-                    $.dialog.close();
-                    location.reload();
-                });
-                dialog.dialog(dialog_container);
-            };
+            )
+            /* Release all keys when the element loses focus. */
+            .blur(function() {
+                keyboard.reset();
+            });
 
-            get_user_stack_status(true);
+        /* Handle paste events when the element is in focus. */
+        $(document).on('paste', function(e) {
+            var text = e.originalEvent.clipboardData.getData('text/plain');
+            if ($(terminal_element).is(":focus")) {
+                terminal_client.setClipboard(text);
+            }
         });
+
+        /* Error handling. */
+        terminal_client.onerror = function(guac_error) {
+            /* Reset and disconnect. */
+            if (keepalive_timer) clearTimeout(keepalive_timer);
+            if (idle_timer) clearTimeout(idle_timer);
+            stack = null;
+            terminal_client.disconnect();
+
+            var dialog = $('#launch_error');
+            var dialog_message =
+                "Could not connect to your lab environment. " +
+                "The client detected an unexpected error. " +
+                "The server's error message was:";
+            var error_message = guac_error.message;
+            /* Special-case the unhelpful "Aborted. See logs"
+                * message, indicating that although we did have a
+                * working connection earlier, we've now lost it (as
+                * opposed to never being able to connect to the
+                * upstream web socket at all). For any other message,
+                * just pass through the error received from
+                * upstream. */
+            if (guac_error.message.toLowerCase().startsWith('aborted')) {
+                dialog_message = "Lost connection to your lab environment."
+                error_message =
+                    "The remote server unexpectedly disconnected. " +
+                    "You can try closing your browser window, " +
+                    "and returning to this page in a few minutes.";
+            }
+            dialog.find('.message').html(dialog_message);
+            dialog.find('.error_msg').html(error_message);
+            dialog.find('input.ok').one('click', function() {
+                $.dialog.close();
+            });
+            dialog.find('input.retry').one('click', function() {
+                $.dialog.close();
+                location.reload();
+            });
+            dialog.dialog(dialog_container);
+        };
+
+        get_user_stack_status(true);
     };
 
     var construct_layout = function() {
@@ -390,17 +386,11 @@ function HastexoXBlock(runtime, element, configuration) {
 
         try {
             terminal_client.connect($.param({
-                'protocol': configuration.protocol,
+                'stack': stack.name,
+                'read_only': configuration.read_only,
                 'width': $('#terminal').width(),
                 'height': $('#terminal').height(),
-                'ip': stack.ip,
                 'port': port,
-                'user': stack.user,
-                'key': stack.key,
-                'password': stack.password,
-                'color_scheme': configuration.color_scheme,
-                'font_name': configuration.font_name,
-                'font_size': configuration.font_size
             }));
             terminal_connected = true;
         } catch (e) {
